Learn R Programming

frontier (version 1.1-8)

frontierTranslogRay: Translog Ray Frontiers

Description

This is a convenient interface for estimating translog stochastic ray frontier models using frontier.

Usage

frontierTranslogRay( yNames, xNames, shifterNames = NULL,
   zNames = NULL, data, … )

Arguments

yNames

a vector of two or more character strings containing the names of the output variables.

xNames

a vector of strings containing the names of the input variables that should be included as linear, quadratic, and interaction terms.

shifterNames

a vector of strings containing the names of the explanatory variables that should be included as shifters only (not in quadratic or interaction terms).

zNames

a vector of strings containing the names of the Z variables (variables explaining the efficiency level).

data

a (panel) data frame that contains the data (see documentation of frontier) NOTE: the variables defined by arguments yNames and xNames must be in natural units; the variables defined by argument xNames are logarithmized internally; the variables defined by arguments shifterNames and zNames are NOT logarithmized internally and hence must be specified as they should be used in the model.

…

further arguments passed to frontierQuad and possibly further to frontier.

Value

frontierTranslogRay returns a list of class frontierTranslogRay (as well as frontierQuad and frontier) containing almost the same elements as returned by frontier. Additionally, it includes following objects:

distance

the “distance” from the origin (zero) to the point of the dependent variables.

theta_i

the “direction” from the origin (zero) to the point of the dependent variables (with i = \(1, ..., N-1\) and \(N\) is the number of outputs).

References

L<U+00F6>thgren, M. (1997) Generalized stochastic frontier production models, Economics Letters, 57, 255-259.

L<U+00F6>thgren, M. (1997) A Multiple Output Stochastic Ray Frontier Production Model, Working Paper Series in Economics and Finance, No. 158, Stockholm School of Economics.

L<U+00F6>thgren, M. (2000) Specification and estimation of stochastic multiple-output production and technical inefficiency Applied Economics, 32, 1533-1540.

See Also

frontier, frontierQuad.

Examples

Run this code
# NOT RUN {
## preparing data
data( germanFarms )
# quantity of crop outputs
germanFarms$qCrop <- germanFarms$vCrop / germanFarms$pOutput
# quantity of animal outputs
germanFarms$qAnimal <- germanFarms$vAnimal / germanFarms$pOutput
# quantity of variable inputs
germanFarms$qVarInput <- germanFarms$vVarInput / germanFarms$pVarInput

# estimate a translog ray production function
estResultRay <- frontierTranslogRay( yNames = c( "qCrop", "qAnimal" ),
   xNames = c( "qLabor", "land", "qVarInput" ),
   data = germanFarms )
summary( estResultRay )
# }

Run the code above in your browser using DataLab